@@ -66,25 +66,25 @@ The constant values for the L</"type"> field.
 
   has type : ro int;
   
-  has nodes : ro List of Eg::Node;
+  has child_nodes_list : ro List of Eg::Node;
   
-  has attributes : rw Eg::Attributes;
+  has attributes_h : ro Hash of string;
   
-  has style : rw Eg::Style;
+  has styles_h : ro Hash of string;
   
   has tag_name : ro string;
   
-  has text_buffer : ro StringBuffer;
+  has value_buffer : ro StringBuffer;
   
-  has parent : Eg::Node;
+  has parent : ro Eg::Node;
   
 =head1 Class Methods
 
-  static method new : Eg::Node ($type : int, $nodes : Eg::Node[] = undef);
+  static method new : Eg::Node ($type : int, $child_nodes : Eg::Node[] = undef);
   
   static method new_document : Eg::Node ($root_node : Eg::Node);
   
-  static method new_element : Eg::Node ($tag_name : string, $attribute_pairs : object[] = undef, $nodes : Eg::Node[] = undef);
+  static method new_element : Eg::Node ($tag_name : string, $attribute_pairs : object[] = undef, $child_nodes : Eg::Node[] = undef);
   
   static method new_text : Eg::Node ($text : string);
 
@@ -102,6 +102,26 @@ The constant values for the L</"type"> field.
   
   method set_text : string ($text : string);
 
+  method attr : string ($name : string);
+  
+  method set_attr : void ($name : string, $value : string);
+  
+  method exists_attr : int ($name : string);
+  
+  method remove_attr : void ($name : string);
+  
+  method attributes : string[] ();
+  
+  method css : string ($name : string);
+  
+  method set_css : void ($name : string, $value : string);
+  
+  method exists_css : int ($name : string);
+  
+  method remove_css : void ($name : string);
+  
+  method styles : string[] ();
+  
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
